﻿using AxisGroupingDemo.Data.Model;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace AxisGroupingDemo.Data
{
    public class DataService
    {
        #region fields

        private List<State> _aqiData;
        private List<Quote> _quotes;

        #endregion

        #region Object Model
        public List<State> AQIData
        {
            get
            {
                if (_aqiData == null)
                    _aqiData = GetAQIData();
                return _aqiData;
            }
        }

        public List<Quote> Quotes
        {
            get
            {
                if (_quotes == null)
                    _quotes = CreateQuotes();
                return _quotes;
            }
        }

        #endregion

        #region Methods

        private List<State> GetAQIData()
        {
            var states = new List<State>();
            var rows = Resources.AQI2017.Split(new string[] { "\r\n" }, StringSplitOptions.RemoveEmptyEntries);
            for (int i = 1; i < rows.Count(); i++)
            {
                var row = rows[i];
                var items = row.Split(',');

                var stateName = items[0];
                var countyName = items[1];
                var pm10 = Convert.ToDouble(items[2]);
                var pm2_5 = Convert.ToDouble(items[3]);

                var state = states.FirstOrDefault(s => s.Name.Equals(stateName));
                if (state == null)
                {
                    state = new State() { Name = stateName };
                    states.Add(state);
                }
                state.Counties.Add(new County
                {
                    Name = countyName,
                    PM10 = pm10,
                    PM2_5 = pm2_5
                });

            }
            return states;
        }

        private List<Quote> CreateQuotes()
        {
            List<Quote> list = new List<Quote>();
            var dt = DateTime.Today;
            var rnd = new Random();
            var price = 1000;
            for (var i = 0; i < 365; i++)
            {
                price += rnd.Next(10) % 2 == 0 ? rnd.Next(50) : -rnd.Next(50);
                list.Add(new Quote() { Time = dt.AddDays(i), Price = price });
            }

            return list;
        }

        #endregion
    }
}
